pub fn init_bg_no_modules(
bg_js: JsValue,
wasm_module: JsValue,
) -> ThreadDispatcherInitExpand description
Start building a thread dispatcher using the bindgen script from the “no-modules” target.
See ThreadDispatcherInit
pub fn init_bg_no_modules(
bg_js: JsValue,
wasm_module: JsValue,
) -> ThreadDispatcherInitStart building a thread dispatcher using the bindgen script from the “no-modules” target.
See ThreadDispatcherInit