pub fn init_bg_web(bg_js: JsValue, wasm_module: JsValue) -> ThreadDispatcherInitExpand description
Start building a thread dispatcher using the bindgen script from the “web” target.
See ThreadDispatcherInit
pub fn init_bg_web(bg_js: JsValue, wasm_module: JsValue) -> ThreadDispatcherInitStart building a thread dispatcher using the bindgen script from the “web” target.
See ThreadDispatcherInit